@@ -597,7 +597,7 @@ typedef enum
     GLOBUS_IO_SECURE_CHANNEL_MODE_CLEAR = 0,
     GLOBUS_IO_SECURE_CHANNEL_MODE_GSI_WRAP,
     GLOBUS_IO_SECURE_CHANNEL_MODE_SSL_WRAP,
-    GLOBUS_IO_SECURE_CHANNEL_MODE_GSI_WRAP_SSL3
+    GLOBUS_IO_SECURE_CHANNEL_MODE_GSI_WRAP_SSL3 /* NO LONGER SUPPORTED */
 } globus_io_secure_channel_mode_t;
 
 globus_result_t
